==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DomainChartSeriesPointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { DomainChartSeriesPointerEventArgsDescription } from "./DomainChartSeriesPointerEventArgsDescription";
/**
 * @hidden
 */
export let DomainChartSeriesPointerEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DomainChartSeriesPointerEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DomainChartSeriesPointerEventArgsDescriptionMetadata.a == null) {
                DomainChartSeriesPointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DomainChartSeriesPointerEventArgsDescriptionMetadata.c(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            }
            if (a.j(DomainChartSeriesPointerEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            DomainChartSeriesPointerEventArgsDescriptionMetadata.b(a);
            a.aa("DomainChartSeriesPointerEventArgs", () => new DomainChartSeriesPointerEventArgsDescription());
            a.z("DomainChartSeriesPointerEventArgs", DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        }
    }
    DomainChartSeriesPointerEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DomainChartSeriesPointerEventArgsDescriptionMetadata, 'DomainChartSeriesPointerEventArgsDescriptionMetadata');
    DomainChartSeriesPointerEventArgsDescriptionMetadata.a = null;
    return DomainChartSeriesPointerEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DomainChartSeriesPointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { DomainChartSeriesPointerEventArgsDescription } from "./DomainChartSeriesPointerEventArgsDescription";
/**
 * @hidden
 */
export let DomainChartSeriesPointerEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DomainChartSeriesPointerEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DomainChartSeriesPointerEventArgsDescriptionMetadata.a == null) {
                DomainChartSeriesPointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DomainChartSeriesPointerEventArgsDescriptionMetadata.c(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            }
            if (a.k(DomainChartSeriesPointerEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            DomainChartSeriesPointerEventArgsDescriptionMetadata.b(a);
            a.ac("DomainChartSeriesPointerEventArgs", () => new DomainChartSeriesPointerEventArgsDescription());
            a.ab("DomainChartSeriesPointerEventArgs", DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        }
    }
    DomainChartSeriesPointerEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DomainChartSeriesPointerEventArgsDescriptionMetadata, 'DomainChartSeriesPointerEventArgsDescriptionMetadata');
    DomainChartSeriesPointerEventArgsDescriptionMetadata.a = null;
    return DomainChartSeriesPointerEventArgsDescriptionMetadata;
})();
